==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ga-IE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Laethanta',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Tuairisc ar Shócmhainní a Dhul in éag.',
    'Expiring_Licenses_Report' => 'Tuarascáil um Cheadúnais a Dhul in éag.',
    'Item_Request_Canceled' => 'Iarratas Mír ar Cealaíodh',
    'Item_Requested' => 'Mír Iarraidh',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Tuarascáil Fardal Íseal',
    'a_user_canceled' => 'Tá úsáideoir tar éis iarratas ar mhír a chealú ar an láithreán gréasáin',
    'a_user_requested' => 'D\'iarr úsáideoir mír ar an láithreán gréasáin',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Ainm Cúlpháirtí',
    'additional_notes' => 'Nótaí Breise',
    'admin_has_created' => 'Tá riarthóir tar éis cuntas a chruthú duit ar: láithreán gréasáin gréasáin.',
    'asset' => 'Sócmhainn',
    'asset_name' => 'Ainm Sócmhainne',
    'asset_requested' => 'Iarrtar sócmhainn',
    'asset_tag' => 'Clib Sócmhainní',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Sannadh Chun',
    'best_regards' => 'Dea-mhéin,',
    'canceled' => 'Ar ceal',
    'checkin_date' => 'Dáta Checkin',
    'checkout_date' => 'Dáta Seiceáil',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Cliceáil ar an nasc ag bun an leathanaigh chun a dheimhniú go bhfuair tú an cúlpháirtí.',
    'click_on_the_link_asset' => 'Cliceáil ar an nasc ag bun an leathanaigh chun a dheimhniú go bhfuair tú an tsócmhainn.',
    'click_to_confirm' => 'Cliceáil ar an nasc seo a leanas le do thoil a dheimhniú: cuntas gréasáin:',
    'current_QTY' => 'QTY Reatha',
    'days' => 'Laethanta',
    'expecting_checkin_date' => 'An Dáta Seiceála Ionchais',
    'expires' => 'Deireadh',
    'hello' => 'Dia dhuit',
    'hi' => 'Haigh',
    'i_have_read' => 'Léigh na téarmaí úsáide agus léigh mé na téarmaí úsáide agus fuair mé an t-ítim seo.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Mír',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Cliceáil ar an nasc seo a leanas chun do chuid focal faire:',
    'login' => 'Logáil isteach:',
    'login_first_admin' => 'Logáil isteach i do shuiteáil Snipe-IT nua ag baint úsáide as na dintiúir thíos:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Ainm',
    'new_item_checked' => 'Rinneadh mír nua a sheiceáil faoi d\'ainm, tá na sonraí thíos.',
    'notes' => 'Nótaí',
    'password' => 'Pasfhocal',
    'password_reset' => 'Athshocraigh Pasfhocal',
    'read_the_terms' => 'Léigh na téarmaí úsáide thíos.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Iarrtar',
    'reset_link' => 'Do Nasc Athshocraigh Pasfhocal',
    'reset_password' => 'Cliceáil anseo chun do phasfhocal a athshocrú:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sraithuimhir',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Soláthraí',
    'tag' => 'Clib',
    'test_email' => 'Tástáil Ríomhphost ó Snipe-IT',
    'test_mail_text' => 'Is tástáil é seo ón gCóras Bainistíochta Sócmhainní Snipe-IT. Má fuair tú é seo, tá an ríomhphost ag obair :)',
    'the_following_item' => 'Rinneadh an méid seo a leanas a sheiceáil i:',
    'to_reset' => 'Chun do phasfhocal gréasáin a athshocrú, comhlánaigh an fhoirm seo:',
    'type' => 'Cineál',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Úsáideoir',
    'username' => 'Ainm Úsáideora',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Fáilte: ainm',
    'welcome_to' => 'Fáilte go dtí: gréasáin!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Do dhintiúir Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ga-IE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Laethanta',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Tuairisc ar Shócmhainní a Dhul in éag.',
    'Expiring_Licenses_Report' => 'Tuarascáil um Cheadúnais a Dhul in éag.',
    'Item_Request_Canceled' => 'Iarratas Mír ar Cealaíodh',
    'Item_Requested' => 'Mír Iarraidh',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Tuarascáil Fardal Íseal',
    'a_user_canceled' => 'Tá úsáideoir tar éis iarratas ar mhír a chealú ar an láithreán gréasáin',
    'a_user_requested' => 'D\'iarr úsáideoir mír ar an láithreán gréasáin',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Ainm Cúlpháirtí',
    'additional_notes' => 'Nótaí Breise',
    'admin_has_created' => 'Tá riarthóir tar éis cuntas a chruthú duit ar: láithreán gréasáin gréasáin.',
    'asset' => 'Sócmhainn',
    'asset_name' => 'Ainm Sócmhainne',
    'asset_requested' => 'Iarrtar sócmhainn',
    'asset_tag' => 'Clib Sócmhainní',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Sannadh Chun',
    'best_regards' => 'Dea-mhéin,',
    'canceled' => 'Ar ceal',
    'checkin_date' => 'Dáta Checkin',
    'checkout_date' => 'Dáta Seiceáil',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Cliceáil ar an nasc ag bun an leathanaigh chun a dheimhniú go bhfuair tú an cúlpháirtí.',
    'click_on_the_link_asset' => 'Cliceáil ar an nasc ag bun an leathanaigh chun a dheimhniú go bhfuair tú an tsócmhainn.',
    'click_to_confirm' => 'Cliceáil ar an nasc seo a leanas le do thoil a dheimhniú: cuntas gréasáin:',
    'current_QTY' => 'QTY Reatha',
    'days' => 'Laethanta',
    'expecting_checkin_date' => 'An Dáta Seiceála Ionchais',
    'expires' => 'Deireadh',
    'hello' => 'Dia dhuit',
    'hi' => 'Haigh',
    'i_have_read' => 'Léigh na téarmaí úsáide agus léigh mé na téarmaí úsáide agus fuair mé an t-ítim seo.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Mír',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Cliceáil ar an nasc seo a leanas chun do chuid focal faire:',
    'login' => 'Logáil isteach',
    'login_first_admin' => 'Logáil isteach i do shuiteáil Snipe-IT nua ag baint úsáide as na dintiúir thíos:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Ainm',
    'new_item_checked' => 'Rinneadh mír nua a sheiceáil faoi d\'ainm, tá na sonraí thíos.',
    'notes' => 'Nótaí',
    'password' => 'Pasfhocal',
    'password_reset' => 'Athshocraigh Pasfhocal',
    'read_the_terms' => 'Léigh na téarmaí úsáide thíos.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Iarrtar',
    'reset_link' => 'Do Nasc Athshocraigh Pasfhocal',
    'reset_password' => 'Cliceáil anseo chun do phasfhocal a athshocrú:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Sraithuimhir',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Soláthraí',
    'tag' => 'Clib',
    'test_email' => 'Tástáil Ríomhphost ó Snipe-IT',
    'test_mail_text' => 'Is tástáil é seo ón gCóras Bainistíochta Sócmhainní Snipe-IT. Má fuair tú é seo, tá an ríomhphost ag obair :)',
    'the_following_item' => 'Rinneadh an méid seo a leanas a sheiceáil i:',
    'to_reset' => 'Chun do phasfhocal gréasáin a athshocrú, comhlánaigh an fhoirm seo:',
    'type' => 'Cineál',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Úsáideoir',
    'username' => 'Ainm Úsáideora',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Fáilte: ainm',
    'welcome_to' => 'Fáilte go dtí: gréasáin!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Do dhintiúir Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
